@@ -5,7 +5,7 @@ from .base import _Jitter, event
 
 class Event(_Jitter):
     """
-    The event base class for creating events (:class:~solver.interface.StateEvent and TimeEvent)
+    The event base class for creating events (:class:`~solver.events.StateEvent` and :class:`~solver.events.TimeEvent`)
     """
     id: str
     _is_external: bool
@@ -53,7 +53,12 @@ class Event(_Jitter):
         self._trigger = True
 
     def reset(self):
-        pass
+        """
+        Called when the solver is reset
+
+        :return:
+        """
+        raise NotImplementedError
 
     def post_event(self, direction: int, interface: Interface, t: float, y: np.array):
         """
@@ -103,6 +108,9 @@ class TimeEvent(Event):
     def post_event(self, direction: int, interface: Interface, t: float, y: np.array):
         pass
 
+    def reset(self):
+        pass
+
 class TimestampedEvent(TimeEvent):
     def __init__(self, id: str, timestamps: np.array, is_external: bool = False):
         self.id = id
@@ -111,7 +119,15 @@ class TimestampedEvent(TimeEvent):
         self._trigger = False
         self._last_ix = 0
 
-    def get_next_event_time(self, interface: Interface, t: float):
+    def get_next_event_time(self, interface: Interface, t: float) -> float:
+        """
+        Returns the next time the time event is triggered
+
+        :param interface: interface: :class:`~solver.interface.Interface`
+        :param t: time
+        :return: the next time this event is triggered
+
+        """
         idx = np.argwhere(self.timestamps[self._last_ix:] >= t) + self._last_ix
         if len(idx) == 0:
             return -1.0
@@ -120,6 +136,15 @@ class TimestampedEvent(TimeEvent):
         return self.timestamps[ix]
 
     def post_event(self, direction: int, interface: Interface, t: float, y: np.array):
+        """
+        increments the event timestamp counter after the event was triggered and the action function run.
+
+        :param direction: not used for time events
+        :param interface: :class:`~solver.interface.Interface`
+        :param t: the current solver time
+        :param y: the current solver states
+        :return: None
+        """
         self._last_ix += 1
 
 class PeriodicTimeEvent(TimeEvent):
@@ -134,14 +159,36 @@ class PeriodicTimeEvent(TimeEvent):
         self.t_next_event = 0.0
         self._trigger = False
 
-    def get_next_event_time(self, interface: Interface, t: float):
+    def get_next_event_time(self, interface: Interface, t: float) -> float:
+        """
+
+        Returns the next time the event is triggered
+        :param interface: :class:`~solver.interface.Interface`
+        :param t: the current time
+        :return: the next time that event is triggered
+
+        """
         return self.t_next_event
 
     def post_event(self, direction: int, interface: Interface, t: float, y: np.array):
+        """
+        Increments the next event by the period :attr:`~solver.events.PeriodicTimeEvent.period`
+
+        :param direction: not used for time events
+        :param interface: :class:`~solver.interface.Interface`
+        :param t: the current time
+        :param y: the solver states
+        :return: None
+        """
         self.t_next_event += self.period
 
+
     def reset(self):
-        self.t_next_event = 0
+        """
+        Resets the event when the solver is reset
+
+        """
+        self.t_next_event = 0.0
         self.clear()
 
 class StateEvent(Event):
@@ -193,6 +240,16 @@ class StateEvent(Event):
         raise NotImplementedError
 
     def post_event(self, interface: Interface, direction: int, t: float, y: np.array):
+        """
+        Sets the last direction and the time of the event as internal states.
+
+        :param interface: :class:`~solver.interface.Interface`
+        :param direction: the direction the event was triggered (up->down == -1, down->up == +1)
+        :param t: the current time
+        :param y: the current solver states
+        :return: None
+
+        """
         self._direction = direction
         self._last_event = t
 
@@ -258,8 +315,21 @@ class StateEvent(Event):
 
         return status, t_r, sol(t_r, t, y)
 
+    def reset(self):
+        """
+        Resets the event when the solver is reset
+
+        :return: None
+        """
+        self._last_event = 0.0
+        self._direction = 0
+        self.clear()
+
 @event
 class MockStateEvent(StateEvent):
+    """
+    Mock state event added in case no state events exist.
+    """
 
     def run_event_action(self, interface: Interface, t: float, y: np.array) -> np.array:
         return y
@@ -272,6 +342,10 @@ class MockStateEvent(StateEvent):
 
 @event
 class MockTimeEvent(TimeEvent):
+    """
+    Mock time event added in case no time events exist.
+    """
+
     def __init__(self, id: str, is_external: bool):
         self.id = id
         self._is_external = is_external
