@@ -125,9 +125,8 @@ class _Interface(_Jitter):
         ix_trigger = np.concatenate((np.argwhere(up), np.argwhere(down)))
 
         ix_event = 0
-        for state_event in literal_unroll(state_events):
+        for state_event in literal_unroll(state_events): # have to unroll to access the event in the tuple
             if ix_event in ix_trigger:
-                state_event.set()
                 eps = 1e-6
                 status, t_event, y_event = state_event.locate_event(self, event_tolerance/10, imax, t_previous,
                                                                    y_previous, t, y, roller, order)
@@ -144,18 +143,19 @@ class _Interface(_Jitter):
             y_event = y_events[:, event_ix]
             direction = np.sign((g_new - g)).astype('int')[event_ix]
             g_new = self.get_state_event_results(t_event, y_event, state_events)
-
-
             bidirectional = directions[event_ix] == 0
 
         ix = 0
-        for state_event in literal_unroll(state_events):
-            if not bidirectional or not event_trigger:
+        for state_event in literal_unroll(state_events): # have to unroll to access the event in the tuple
+            if not event_trigger: # no event triggered -> out
                 break
-            if ix == event_ix and state_event._direction != direction and \
+
+            if bidirectional and ix == event_ix and state_event._direction != direction and \
                     abs(t_event - state_event._last_event) < state_event._debounce:
-                state_event.clear()
                 event_trigger = False
+                break
+            elif ix == event_ix:
+                state_event.set()
 
             ix += 1
 
